@@ -9,21 +9,7 @@ from typing_extensions import Generator
 
 from patchwork.common.utils.utils import get_current_branch
 from patchwork.logger import logger
-from patchwork.step import Step
-
-
-def get_slug_from_remote_url(remote_url: str) -> str:
-    # TODO: consider using https://github.com/nephila/giturlparse instead
-    if remote_url.startswith("git@"):
-        # ssh
-        _, _, potential_slug = remote_url.partition(":")
-    else:
-        potential_slug = "/".join(remote_url.split("/")[-2:])
-
-    if potential_slug.endswith(".git"):
-        potential_slug = potential_slug[:-4]
-
-    return potential_slug
+from patchwork.step import Step, StepStatus
 
 
 @contextlib.contextmanager
@@ -114,8 +100,7 @@ class CommitChanges(Step):
     required_keys = {"modified_code_files"}
 
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
@@ -141,7 +126,7 @@ class CommitChanges(Step):
         modified_files = {Path(modified_code_file["path"]).resolve() for modified_code_file in self.modified_code_files}
         true_modified_files = modified_files.intersection(repo_changed_files.union(repo_untracked_files))
         if not self.enabled or len(true_modified_files) < 1:
-            logger.debug("Branch creation is disabled.")
+            self.set_status(StepStatus.SKIPPED, "Branch creation is disabled.")
             from_branch = get_current_branch(repo)
             from_branch_name = from_branch.name if not from_branch.is_remote() else from_branch.remote_head
             return dict(target_branch=from_branch_name)
@@ -156,7 +141,6 @@ class CommitChanges(Step):
                 repo.git.add(modified_file)
                 commit_with_msg(repo, f"Patched {modified_file}")
 
-            logger.info(f"Run completed {self.__class__.__name__}")
             return dict(
                 base_branch=from_branch,
                 target_branch=to_branch,
